Update of /cvsroot/monetdb/pathfinder/compiler/semantics
In directory sc8-pr-cvs16:/tmp/cvs-serv21725/compiler/semantics
Modified Files:
xquery_fo.c
Log Message:
After lengthy discussion about the tijah:query[-id] overloading problems we
decided to split the function (family) into to seperate families.
tijah:query(node*, string) as node*
tijah:query(node*, string, node) as node*
tijah:query-id(node*, string) as integer
tijah:query-id(node*, string, node) as integer
tijah:queryall(string) as node*
tijah:queryall(string, node) as node*
tijah:queryall-id(string) as integer
tijah:queryall-id(string, node) as integer
The first 4 functions are the "query" family of functions where you have to
supply a startNode sequence as first argument. These startNodes are the nodes
from which the nexi query starts its search. The second "queryall" family of
functions omits the startNodes and searches the entire index.
Index: xquery_fo.c
===================================================================
RCS file: /cvsroot/monetdb/pathfinder/compiler/semantics/xquery_fo.c,v
retrieving revision 1.125
retrieving revision 1.126
diff -u -d -r1.125 -r1.126
--- xquery_fo.c 9 May 2007 06:48:05 -0000 1.125
+++ xquery_fo.c 10 May 2007 09:26:06 -0000 1.126
@@ -2056,19 +2056,26 @@
.arity = 1, .sig_count = 1, .sigs = { {
.par_ty = (PFty_t[]) { PFty_xs_anyNode () },
.ret_ty = PFty_docmgmt () } } }
- , /* tijah:query-id(string) as integer */
- { .ns = PFns_tijah, .loc = "query-id",
+ , /* tijah:queryall-id(string) as integer */
+ { .ns = PFns_tijah, .loc = "queryall-id",
.arity = 1, .sig_count = 1, .sigs = { {
.par_ty = (PFty_t[]) { PFty_xs_string () },
.ret_ty = PFty_xs_integer () },
} }
- , /* tijah:query-id(string, node) as integer */
- { .ns = PFns_tijah, .loc = "query-id",
+ , /* tijah:queryall-id(string, node) as integer */
+ { .ns = PFns_tijah, .loc = "queryall-id",
.arity = 2, .sig_count = 1, .sigs = { {
.par_ty = (PFty_t[]) { PFty_xs_string (),
PFty_xs_anyNode () },
.ret_ty = PFty_xs_integer () },
} }
+ , /* tijah:query-id(node*, string) as integer */
+ { .ns = PFns_tijah, .loc = "query-id",
+ .arity = 2, .sig_count = 1, .sigs = { {
+ .par_ty = (PFty_t[]) { PFty_star (PFty_xs_anyNode ()),
+ PFty_xs_string ()},
+ .ret_ty = PFty_xs_integer () },
+ } }
, /* tijah:query-id(node*, string, node) as integer */
{ .ns = PFns_tijah, .loc = "query-id",
.arity = 3, .sig_count = 1, .sigs = { {
@@ -2077,19 +2084,26 @@
PFty_xs_anyNode ()},
.ret_ty = PFty_xs_integer () },
} }
- , /* tijah:query(string) as node* */
- { .ns = PFns_tijah, .loc = "query",
+ , /* tijah:queryall(string) as node* */
+ { .ns = PFns_tijah, .loc = "queryall",
.arity = 1, .sig_count = 1, .sigs = { {
.par_ty = (PFty_t[]) { PFty_xs_string () },
.ret_ty = PFty_star (PFty_xs_anyNode ()) },
} }
- , /* tijah:query(string, node) as node* */
- { .ns = PFns_tijah, .loc = "query",
+ , /* tijah:queryall(string, node) as node* */
+ { .ns = PFns_tijah, .loc = "queryall",
.arity = 2, .sig_count = 1, .sigs = { {
.par_ty = (PFty_t[]) { PFty_xs_string (),
PFty_xs_anyNode () },
.ret_ty = PFty_star (PFty_xs_anyNode ()) },
} }
+ , /* tijah:query(node*, string) as node* */
+ { .ns = PFns_tijah, .loc = "query",
+ .arity = 2, .sig_count = 1, .sigs = { {
+ .par_ty = (PFty_t[]) { PFty_star (PFty_xs_anyNode ()),
+ PFty_xs_string ()},
+ .ret_ty = PFty_star (PFty_xs_anyNode ()) },
+ } }
, /* tijah:query(node*, string, node) as node* */
{ .ns = PFns_tijah, .loc = "query",
.arity = 3, .sig_count = 1, .sigs = { {
-------------------------------------------------------------------------
This SF.net email is sponsored by DB2 Express
Download DB2 Express C - the FREE version of DB2 express and take
control of your XML. No limits. Just data. Click to get it now.
http://sourceforge.net/powerbar/db2/
_______________________________________________
Monetdb-pf-checkins mailing list
[email protected]
https://lists.sourceforge.net/lists/listinfo/monetdb-pf-checkins